@@ -10,7 +10,7 @@ HTML::GoogleMaps::V3 - a simple wrapper around the Google Maps API
 
 =head1 VERSION
 
-0.07
+0.08
 
 =head1 SYNOPSIS
 
@@ -60,6 +60,8 @@ Valid options are:
 
 =item width => width (in pixels or using your own unit)
 
+=item z_axis => place on z-axis (e.g. -1 to ensure scrolling works)
+
 =back
 
 =back
@@ -72,7 +74,7 @@ use warnings;
 use Geo::Coder::Google;
 use Template;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub new {
     my ( $class,%opts ) = @_;
@@ -81,7 +83,10 @@ sub new {
         %opts,
         points     => [],
         poly_lines => [],
-        geocoder   => Geo::Coder::Google->new,
+        geocoder   => Geo::Coder::Google->new(
+            apidriver => 3,
+            ( $opts{'api_key'} ? ( key => $opts{'api_key'} ) : () ),
+        ),
     }, $class );
 }
 
@@ -366,8 +371,10 @@ sub onload_render {
     $header =~ s/__KEY__/$key/;
 
     my $map = sprintf(
-        '<div id="%s" style="width: %s; height: %s"></div>',
+        '<div id="%s" style="width: %s; height: %s%s"></div>',
         @{$self}{qw/ id width height / },
+        exists($self->{'z_axis'})
+            ? '; z-axis: ' . $self->{'z_axis'} : ''
     );
 
     my $out;
@@ -398,6 +405,8 @@ Nate Mueller <nate@cs.wisc.edu> - Original Author
 
 Lee Johnson <leejo@cpan.org> - Maintainer of this fork
 
+Nigel Horne - Contributor of several patches
+
 =cut
 
 1;
